package sample;

import java.nio.charset.StandardCharsets;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.time.LocalDateTime;
import java.util.stream.Collectors;
import java.util.stream.Stream;

import javax.annotation.PostConstruct;
import javax.ejb.Singleton;
import javax.ejb.Startup;
import javax.persistence.EntityManager;
import javax.persistence.PersistenceContext;

import sample.entity.Account;
import sample.entity.Password;
import sample.entity.Role;
import sample.entity.Shinsei;
import sample.entity.Status;

/**
 * サンプルデータを作成するクラスです。
 * 
 * <p>
 * 紙面での解説はありませんが、技術としてはEJBを利用しています。
 * </p>
 *
 */
//EJBのシングルトンセッションビーンであることを示すアノテーションです。
@Singleton
//アプリケーションの起動時にこのシングルトンセッションビーンを
//初期化することを示すアノテーションです。
@Startup
public class SampleDataInitializer {

    @PersistenceContext
    private EntityManager em;

    @PostConstruct
    public void initializeSampleData() {

        Account uragami = new Account();
        uragami.setName("backpaper0");
        uragami.setDisplay("うらがみ");
        uragami.setRole(Role.APPLICANT);
        em.persist(uragami);

        Account irof = new Account();
        irof.setName("irof");
        irof.setDisplay("のざき ひろふみ");
        irof.setRole(Role.APPROVER);
        em.persist(irof);

        try {
            MessageDigest md = MessageDigest.getInstance("SHA-256");

            Password uragamiSecret = new Password();
            uragamiSecret.setId(uragami.getId());
            uragamiSecret.setHashed(md.digest("backpaper0".getBytes(StandardCharsets.UTF_8)));
            em.persist(uragamiSecret);

            Password irofSecret = new Password();
            irofSecret.setId(irof.getId());
            irofSecret.setHashed(md.digest("irof".getBytes(StandardCharsets.UTF_8)));
            em.persist(irofSecret);

        } catch (NoSuchAlgorithmException e) {
            throw new RuntimeException(e);
        }

        Shinsei javaEngineerTrainingBook = new Shinsei();
        javaEngineerTrainingBook.setDescription("「Javaエンジニア養成読本」購入申請");
        javaEngineerTrainingBook.setDetail(Stream
                .of("若手Javaエンジニアの教本として利用したいため「Javaエンジニア養成読本」の購入を申請します。",
                        "http://gihyo.jp/book/2014/978-4-7741-6931-6")
                .collect(Collectors.joining(System.lineSeparator())));
        javaEngineerTrainingBook.setStatus(Status.APPROVED);
        javaEngineerTrainingBook.setApplicant(uragami);
        javaEngineerTrainingBook.setAppliedAt(LocalDateTime.now());
        javaEngineerTrainingBook.setReason("承認します。");
        javaEngineerTrainingBook.setApprover(irof);
        javaEngineerTrainingBook.setApprovedAt(LocalDateTime.now());
        em.persist(javaEngineerTrainingBook);

        Shinsei perfectJavaEE = new Shinsei();
        perfectJavaEE.setDescription("「パーフェクトJava EE」購入申請");
        perfectJavaEE.setDetail(Stream
                .of("Java EEへの理解をより深めるため「パーフェクトJava EE」の購入を申請します。",
                        "http://gihyo.jp/book/2016/978-4-7741-8316-9")
                .collect(Collectors.joining(System.lineSeparator())));
        perfectJavaEE.setStatus(Status.APPLYING);
        perfectJavaEE.setApplicant(uragami);
        perfectJavaEE.setAppliedAt(LocalDateTime.now());
        em.persist(perfectJavaEE);
    }
}
