package sample.data;

import javax.annotation.Resource;
import javax.annotation.sql.DataSourceDefinition;
import javax.enterprise.context.Dependent;
import javax.enterprise.inject.Produces;
import javax.sql.DataSource;

/**
 * データソースをCDIで扱えるようにするためのプロデュースメソッドを提供するクラスです。
 *
 */
@Dependent
//データソースを定義するアノテーションです。
@DataSourceDefinition(
        name = "java:global/jdbc/sample",
        className = "org.h2.jdbcx.JdbcDataSource",
        url = "jdbc:h2:mem:sample;DB_CLOSE_DELAY=-1",
        user = "sa",
        password = "secret")
public class DataSourceProvider {

    /**
     * データソース
     */
    //クラスに注釈したアノテーションで定義した
    //データソースをインジェクションしています。
    @Resource(lookup = "java:global/jdbc/sample")
    private DataSource dataSource;

    /**
     * データソースを返します。
     * 
     * @return データソース
     */
    //戻り値でCDI管理ビーンを定義するプロデュースメソッド
    //であることを表すアノテーションです。
    @Produces
    public DataSource getDataSource() {
        return dataSource;
    }
}
