package sample.entity;

import java.sql.Timestamp;
import java.time.LocalDateTime;
import java.time.ZoneOffset;
import java.util.Optional;

import javax.persistence.AttributeConverter;
import javax.persistence.Converter;

/**
 * JPAのエンティティでLocalDateTimeを使うための変換クラスです。
 *
 */
@Converter
public class LocalDateTimeConverter implements AttributeConverter<LocalDateTime, Timestamp> {

    /**
     * LocalDateTimeの値をTimestampに変換します。
     */
    @Override
    public Timestamp convertToDatabaseColumn(LocalDateTime attribute) {
        return Optional.ofNullable(attribute)
                .map(x -> x.toEpochSecond(ZoneOffset.UTC))
                .map(Timestamp::new)
                .orElse(null);
    }

    /**
     * Timestampの値をLocalDateTimeに変換します。
     */
    @Override
    public LocalDateTime convertToEntityAttribute(Timestamp dbData) {
        return Optional.ofNullable(dbData)
                .map(Timestamp::toLocalDateTime)
                .orElse(null);
    }
}
