package sample.entity;

import java.io.Serializable;
import java.time.LocalDateTime;

import javax.persistence.Convert;
import javax.persistence.Entity;
import javax.persistence.GeneratedValue;
import javax.persistence.Id;
import javax.persistence.ManyToOne;

/**
 * 申請データを表すエンティティクラスです。
 *
 */
@Entity
public class Shinsei implements Serializable {

    /**
     * ID
     */
    @Id
    @GeneratedValue
    private Long id;
    /**
     * 申請者
     */
    @ManyToOne
    private Account applicant;
    /**
     * 申請日時
     */
    @Convert(converter = LocalDateTimeConverter.class)
    private LocalDateTime appliedAt;
    /**
     * 概要
     */
    private String description;
    /**
     * 詳細
     */
    private String detail;
    /**
     * ステータス
     */
    private Status status;
    /**
     * 承認(棄却)者
     */
    @ManyToOne
    private Account approver;
    /**
     * 承認(棄却)日時
     */
    @Convert(converter = LocalDateTimeConverter.class)
    private LocalDateTime approvedAt;
    /**
     * 承認(棄却)理由
     */
    private String reason;

    /**
     * IDを返します。
     * 
     * @return ID
     */
    public Long getId() {
        return id;
    }

    /**
     * IDを設定します。
     * 
     * @param id ID
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * 申請者を返します。
     * 
     * @return 申請者
     */
    public Account getApplicant() {
        return applicant;
    }

    /**
     * 申請者を設定します。
     * 
     * @param applicant 申請者
     */
    public void setApplicant(Account applicant) {
        this.applicant = applicant;
    }

    /**
     * 申請日時を返します。
     * 
     * @return 申請日時
     */
    public LocalDateTime getAppliedAt() {
        return appliedAt;
    }

    /**
     * 申請日時を設定します。
     * 
     * @param appliedAt 申請日時
     */
    public void setAppliedAt(LocalDateTime appliedAt) {
        this.appliedAt = appliedAt;
    }

    /**
     * 概要を返します。
     * 
     * @return 概要
     */
    public String getDescription() {
        return description;
    }

    /**
     * 概要を設定します。
     * 
     * @param description 概要
     */
    public void setDescription(String description) {
        this.description = description;
    }

    /**
     * 詳細を返します。
     * 
     * @return 詳細
     */
    public String getDetail() {
        return detail;
    }

    /**
     * 詳細を設定します。
     * 
     * @param detail 詳細
     */
    public void setDetail(String detail) {
        this.detail = detail;
    }

    /**
     * ステータスを返します。
     * 
     * @return ステータス
     */
    public Status getStatus() {
        return status;
    }

    /**
     * ステータスを設定します。
     * 
     * @param status ステータス
     */
    public void setStatus(Status status) {
        this.status = status;
    }

    /**
     * 承認(棄却)者を返します。
     * 
     * @return 承認(棄却)者
     */
    public Account getApprover() {
        return approver;
    }

    /**
     * 承認(棄却)者を設定します。
     * 
     * @param approver 承認(棄却)者
     */
    public void setApprover(Account approver) {
        this.approver = approver;
    }

    /**
     * 承認(棄却)日時を返します。
     * 
     * @return 承認(棄却)日時
     */
    public LocalDateTime getApprovedAt() {
        return approvedAt;
    }

    /**
     * 承認(棄却)日時を設定します。
     * 
     * @param approvedAt 承認(棄却)日時
     */
    public void setApprovedAt(LocalDateTime approvedAt) {
        this.approvedAt = approvedAt;
    }

    /**
     * 承認(棄却)理由を返します。
     * 
     * @return 承認(棄却)理由
     */
    public String getReason() {
        return reason;
    }

    /**
     * 承認(棄却)理由を設定します。
     * 
     * @param reason 承認(棄却)理由
     */
    public void setReason(String reason) {
        this.reason = reason;
    }
}
