package sample.resource;

import javax.enterprise.context.RequestScoped;
import javax.inject.Inject;
import javax.ws.rs.Consumes;
import javax.ws.rs.FormParam;
import javax.ws.rs.POST;
import javax.ws.rs.Path;
import javax.ws.rs.WebApplicationException;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.Response.Status;

import sample.entity.Account;
import sample.security.UserImpl;
import sample.service.SecurityService;

/**
 * ログイン・ログアウトに関するHTTPリクエストのエンドポイントとなるリソースクラスです。
 *
 */
@RequestScoped
@Path("")
public class SecurityResource {

    @Inject
    private SecurityService service;
    @Inject
    private UserImpl user;

    /**
     * ログインします。
     * 
     * @param userId ユーザーID
     * @param password パスワード
     */
    @Path("login")
    @POST
    @Consumes(MediaType.APPLICATION_FORM_URLENCODED)
    public void login(@FormParam("userId") String userId, @FormParam("password") String password) {
        Account account = service.login(userId, password).orElseThrow(
                () -> new WebApplicationException(Response.status(Status.UNAUTHORIZED).build()));
        user.login(account);
    }

    /**
     * ログアウトします。
     */
    @Path("logout")
    @POST
    public void logout() {
        user.logout();
    }
}
