package sample.security;

import java.io.IOException;

import javax.enterprise.context.ApplicationScoped;
import javax.inject.Inject;
import javax.ws.rs.container.ContainerRequestContext;
import javax.ws.rs.container.ContainerRequestFilter;
import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.Response.Status;
import javax.ws.rs.ext.Provider;

import sample.ui.Jsp;

/**
 * ログインしていないユーザーからリソースを保護するための仕組みです。
 *
 */
//JAX-RSにこのクラスを認識させるためのアノテーションです。
@Provider
@ApplicationScoped
//このクラスとリソースクラスをアノテーションで紐付けるためにProtectedで注釈しています。
@Protected
public class Protection implements ContainerRequestFilter {

    @Inject
    private UserImpl user;

    @Override
    public void filter(ContainerRequestContext requestContext) throws IOException {
        if (user.getAccount().isPresent() == false) {
            Response response = Response.status(Status.FORBIDDEN)
                    .entity(new Jsp("/WEB-INF/views/login.jsp")).type(MediaType.TEXT_HTML_TYPE)
                    .build();
            requestContext.abortWith(response);
        }
    }
}
