package sample.security;

import javax.enterprise.context.Dependent;
import javax.enterprise.event.Observes;
import javax.inject.Inject;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;

/**
 * セッションに関する処理をまとめたクラスです。
 *
 */
@Dependent
public class SessionManager {

    @Inject
    private HttpServletRequest request;
    @Inject
    private HttpSession session;

    /**
     * セッションIDをリフレッシュします。
     * 
     * <p>
     * セッションハイジャック防止のための対策の一環です。
     * </p>
     * 
     * @param event ログインイベント
     */
    public void changeSessionId(@Observes LoggedIn event) {
        request.changeSessionId();
    }

    /**
     * セッションを破棄します。
     * 
     * @param event ログアウトイベント
     */
    public void invalidate(@Observes LoggedOut event) {
        session.invalidate();
    }
}
