package sample.security;

import java.io.Serializable;
import java.util.Optional;

import javax.enterprise.context.SessionScoped;
import javax.enterprise.event.Event;
import javax.inject.Inject;

import sample.entity.Account;

/**
 * Userの実装クラスです。
 * このクラスはセッションスコープで管理されます。
 *
 */
@SessionScoped
//セッションスコープのCDI管理ビーンはSerializableを実装します。
public class UserImpl implements User, Serializable {

    @Inject
    private Event<LoggedIn> loggedInEvent;
    @Inject
    private Event<LoggedOut> loggedOutEvent;

    private Account account;

    @Override
    public Optional<Account> getAccount() {
        if (account == null) {
            return Optional.empty();
        }
        Account copied = copy(account);
        return Optional.of(copied);
    }

    /**
     * 指定されたアカウントでログイン状態にします。
     * 
     * @param account アカウント
     */
    public void login(Account account) {
        Account copied = copy(account);
        this.account = copied;
        loggedInEvent.fire(new LoggedIn());
    }

    /**
     * ログアウトします。
     * 
     */
    public void logout() {
        loggedOutEvent.fire(new LoggedOut());
    }

    private static Account copy(Account account) {
        Account copied = new Account();
        copied.setId(account.getId());
        copied.setName(account.getName());
        copied.setDisplay(account.getDisplay());
        copied.setRole(account.getRole());
        return copied;
    }
}
