package sample.service;

import java.nio.charset.StandardCharsets;
import java.security.MessageDigest;
import java.security.NoSuchAlgorithmException;
import java.util.Arrays;
import java.util.Optional;

import javax.enterprise.context.ApplicationScoped;
import javax.inject.Inject;
import javax.persistence.EntityManager;
import javax.persistence.NoResultException;
import javax.transaction.Transactional;

import sample.entity.Account;
import sample.entity.Password;

/**
 * ログインに関するビジネスロジックです。
 *
 */
@ApplicationScoped
@Transactional
public class SecurityService {

    @Inject
    private EntityManager em;

    /**
     * 認証します。
     * 
     * @param userId ユーザーID
     * @param rawPassword パスワード
     * @return 認証に成功したら該当アカウントを返します
     */
    public Optional<Account> login(String userId, String rawPassword) {
        try {
            String query = "SELECT a FROM Account a WHERE a.name = :name";
            Account account = em.createQuery(query, Account.class).setParameter("name", userId)
                    .getSingleResult();

            Password password = em.find(Password.class, account.getId());

            byte[] bs = MessageDigest.getInstance("SHA-256")
                    .digest(rawPassword.getBytes(StandardCharsets.UTF_8));

            if (Arrays.equals(bs, password.getHashed())) {
                return Optional.of(account);
            }

            return Optional.empty();

        } catch (NoResultException e) {
            return Optional.empty();

        } catch (NoSuchAlgorithmException e) {
            throw new RuntimeException(e);
        }
    }
}
