package sample.ui;

/**
 * リソースメソッドからビューテンプレートのパスと、ビューに渡す値を連携するためのクラスです。
 *
 */
public class Jsp {
    /**
     * ビューテンプレートのパス
     */
    private final String path;
    /**
     * ビューに渡す値
     */
    private final Object model;

    /**
     * ビューテンプレートのパスとビューに渡す値を設定したインスタンスを構築します。
     * 
     * @param path ビューテンプレートのパス
     * @param model ビューに渡す値
     */
    public Jsp(String path, Object model) {
        this.path = path;
        this.model = model;
    }

    /**
     * ビューテンプレートのパスを設定したインスタンスを構築します。
     * 
     * @param path ビューテンプレートのパス
     */
    public Jsp(String path) {
        this(path, null);
    }

    /**
     * ビューテンプレートのパスを返します。
     * 
     * @return ビューテンプレートのパス
     */
    public String getPath() {
        return path;
    }

    /**
     * ビューに渡す値を返します。
     * 
     * @return ビューに渡す値
     */
    public Object getModel() {
        return model;
    }
}
